@@ -11,6 +11,7 @@
 /* Please keep this in alphabetical order */
 static gchar *contributors[] = {
 	"J\xc3\xa9r\xc3\xb4me Abela",
+	"Rob Adams",
 	"Lauri Alanko",
 	"Seth Alves",
 	"Shawn T. Amundson",
@@ -106,6 +107,10 @@ static gchar *contributors[] = {
 	"Dave Glowacki",
 	"Scott Goehring",
 	"Randy Gordon",
+	"Ted Gould",
+	"Dodji Seketeli",
+	"Christophe Fergeau",
+	"Gael Chamoulaud",
 	"Kenny Graunke",
 	"Jamin Philip Gray",
 	"Dov Grobgeld",
@@ -296,6 +301,7 @@ static gchar *contributors[] = {
 	"Kimball Thurston",
 	"Chris Toshok",
 	"Christoph Toshok",
+	"Malcolm Tredinnick",
 	"Tom Tromey",
 	"Jon Trowbridge",
 	"Vincent Untz",
